function [r_p_n] = calc_corrs_dt(r1,r2)

% This function is the same as calc_corrs but linearly detrends the values.
%
% The function takes as input two records, 1 and 2.
% Each record is given by two vectors:
% - a time vector, t, either depth in core or modeled age.
% - a value vector, v, which is the quantity measured at the corresponding
% time.

t1= r1(:,1);
v1= r1(:,2);
t2= r2(:,1);
v2= r2(:,2);

% Define a minimum number of interpolated points
nmin = 4 ;

% The output is a 2-element vector containing the correlation coefficient, 
% r, and the p-value.

% Use t1 as common time axis (i.e. interpolation is done onto the first
% record).

v2_on_t1 = interp1(t2,v2,t1);

% Identify depths/ages found in both cores, since can't correlate over
% NaNs and don't want to go past limits of shorter record.

indfin = find(t1 < max(t2) & isfinite(v2_on_t1));

% Calculate number of pairs used in correlation
n = numel(indfin) ;

stdev = ~ismember(0, std([v1(indfin), v2_on_t1(indfin)]));

if n > nmin && stdev
    % detrend the variables
    v1_dt = detrend(v1(indfin));
    v2_dt = detrend(v2_on_t1(indfin));

    % Calculate the correlation coefficient, r, and p-value 
    [r,p] = corrcoef(v1_dt,v2_dt) ;

    % Plots for debugging the interpolation and indexing 
    % figure
    % plot(t1(indfin),v1(indfin), t1(indfin),v2_on_t1(indfin))
    % title([num2str(i) ',' num2str(j)])

    % Rearrange as a vector for convenience

    r_p_n = [r(1,2) ; p(1,2) ; n] ;
else
    r_p_n = [0 ; 1 ; n] ;   
end

end