% INCORE

% Calculate correlations within individual cores at one site
% (no inter-core interpolations)

% Generate the data array
run(sprintf('%s_records.m',sitename))

% A colour map for the patchwork plots
cmap = redblue ;

% Clear some variables
clear numrec
clear recnames
clear corr_out
clear t_summary
clear typesum
clear corrmat_names
clear corrmat_types
clear recpairs
clear site_corr
clear site_corr_dt


% START
% Check the number of cores at the site
numcores = size(cores,1);

% Initialize summary matrices
recpairs      = zeros(6,2,numcores) ; % pairtypes, depth/year, cores
sigcorr_no    = zeros(6,2,numcores) ;
sigcorr_dt_no = zeros(6,2,numcores) ;
allpairs={[] [] [] [] [] [] []} ;
allpairs_dt={[] [] [] [] [] [] []} ;


% Loop through all cores
for k=1:numcores

for drt=2:3     
% Clear reused arrays
clear corrmat_names
clear corrmat_types

    
if drt==2 % vs. depth
% Check the number of records vs. depth within the core 
% (Note first record is time-model, so left out of correlations)
    numrec = size(cores{k,2},1)-1;
    timeax = 'depth' ;
    records = cores{k,drt}(2:numrec+1,:) ;
else
% Check number of records vs. time
    numrec = size(cores{k,3},1);
    timeax = 'year' ; 
    records = cores{k,drt} ;
end

% Check that there are at least 2 records 
if numrec > 1  % then go through calculations
    
% Find the names of the measured records
recnames = {records{:,1}} ;

if makefigs
% Initialize the figure
f1 = figure ;
set(gcf,'Position',[10 200 2500 2000],'Color','w') ;
end

% FIRST, GO THROUGH ALL PAIRS, NOT DETRENDED

% Initialize the correlation matrix
corr_out=zeros(numrec,numrec,3);
% Loop over all the possible combinations within the core
for i=1:numrec 
    for j=1:numrec 
        [typesum,typeid,fishtype]=checktype(records{i,3},records{j,3});
        % Check that records are both content OR both flux
        % Note this isn't quite right for SST, which is neither, and won't
        % be compared with fluxes as it is now
        if mod(typesum,2) == 0 
            rec1 = records{i,2};
            rec2 = records{j,2};
            corr_out(i,j,:) = calc_corrs(rec1,rec2);
            % write out pair
            allpairs = [allpairs; {k,[records{i,1} ' v. ' records{j,1}], typeid, fishtype,corr_out(i,j,1),corr_out(i,j,2),corr_out(i,j,3)}];
            if makefigs
            % plot the records as sent to the calculation script
            subplot(numrec,numrec,(i)+numrec*(j-1))
            plotyy(rec1(:,1),rec1(:,2),rec2(:,1),rec2(:,2))
            end
        end
        corrmat_names{i,j} = [records{i,1} ' v. ' records{j,1}];
        corrmat_types(i,j) = typeid;
    end
end

if makefigs
% Print out the matrix of curve plots
export_fig(f1,sprintf('%s/figures/%s.%s.curves.pdf', sitename, cores{k,1}, timeax), '-pdf', '-painters')
end

% Save the correlation matrix to the site summary cell-array
site_corr{k,drt-1} = corr_out ;

% Identify which correlations are significant, in terms of p and n
sig_p_n = corr_out(:,:,2) < sig_p_lim & corr_out(:,:,3) > sig_n_lim ;
% Check that both directions of interpolation produce significance
sig_sym = sig_p_n .* sig_p_n' ;

% Create a flat array of the r values
corrs = squeeze(corr_out(:,:,1)) ;
% Set diagonal (self-correlations) to 0
corrs(1:numrec+1:numrec^2) = 0 ;
% Create a 2d array of the significant r values
sigcorrs = corrs .* sig_sym ;
% Likewise for p and n
sigcorrs_p = squeeze(corr_out(:,:,2) .* sig_sym) ;
sigcorrs_n = squeeze(corr_out(:,:,3) .* sig_sym) ;

% Write out variable pairs and correlation statistics in a list

ind=find(sigcorrs);
ind1=find(sigcorrs & corrmat_types ==1);
ind2=find(sigcorrs & corrmat_types ==2);
ind3=find(sigcorrs & corrmat_types ==3);
ind4=find(sigcorrs & corrmat_types ==4);
ind5=find(sigcorrs & corrmat_types ==5);
ind6=find(sigcorrs & corrmat_types ==6);
pair_names = corrmat_names(ind);
r_values = sigcorrs(ind) ;
p_values = sigcorrs_p(ind) ;
n_tested = sigcorrs_n(ind) ;
sigcorrs_table = table(pair_names, r_values, p_values, n_tested)
writetable(sigcorrs_table,sprintf('%s/tables/%s.%s.sigcorrs.txt', sitename, cores{k,1},timeax));

% Add up the number of records tested
recpairs(:,drt-1,k) = [floor(length(find(corrs & corrmat_types ==1))./2), 
    floor(length(find(corrs & corrmat_types ==2))./2),
    floor(length(find(corrs & corrmat_types ==3))./2),
    floor(length(find(corrs & corrmat_types ==4))./2),
    floor(length(find(corrs & corrmat_types ==5))./2),
    floor(length(find(corrs & corrmat_types ==6))./2)];
% Add number of significant correlations
sigcorr_no(:,drt-1,k) = [floor(length(ind1)./2),
    floor(length(ind2)./2),
    floor(length(ind3)./2),
    floor(length(ind4)./2),
    floor(length(ind5)./2),
    floor(length(ind6)./2)];



if makefigs
% Plot significant correlations
f2 = figure ;
set(gcf,'Position',[10 200 600 500],'Color','w') ;
imagesc(sigcorrs,[-1 1])
colormap(cmap)
xticks([1:1:numrec]);
xticklabels(recnames);
yticks([1:1:numrec]);
yticklabels(recnames);
xtickangle(45);
title(cores{k,1});
export_fig(sprintf('%s/figures/%s.%s.corrs.pdf', sitename, cores{k,1},timeax), '-pdf', '-opengl')
end







% Then, detrended

corr_out=zeros(numrec,numrec,3);

for i=1:numrec ;
    for j=1:numrec ;
        [typesum,typeid,fishtype]=checktype(records{i,3},records{j,3});
        % Check that records are both content OR both flux
        % Note this isn't quite right for SST, which is neither, and won't
        % be compared with fluxes as it is now
        if mod(typesum,2) == 0 
            rec1 = records{i,2};
            rec2 = records{j,2};
            corr_out(i,j,:) = calc_corrs_dt(rec1,rec2);
            % write out pair
            allpairs_dt = [allpairs_dt; {k,[records{i,1} ' v. ' records{j,1}], typeid, fishtype,corr_out(i,j,1),corr_out(i,j,2),corr_out(i,j,3)}];
            corrmat_types(i,j) = typeid;
        end
    end
end

% Save the correlation matrix to the site summary cell-array
site_corr_dt{k,drt-1} = corr_out ;


% Identify which correlations are significant, in terms of p and n
sig_p_n = corr_out(:,:,2) < sig_p_lim & corr_out(:,:,3) > sig_n_lim ;
% Check that both directions of interpolation produce significance
sig_sym = sig_p_n .* sig_p_n' ;

corrs = squeeze(corr_out(:,:,1)) ;
% Set diagonal (self-correlations) to 0
corrs(1:numrec+1:numrec^2) = 0 ;
sigcorrs_dt = corrs .* sig_sym ;
sigcorrs_p_dt = squeeze(corr_out(:,:,2) .* sig_sym) ;
sigcorrs_n_dt = squeeze(corr_out(:,:,3) .* sig_sym) ;

% Write out variable pairs and correlation statistics in a list
ind=find(sigcorrs_dt);
ind1=find(sigcorrs_dt & corrmat_types ==1);
ind2=find(sigcorrs_dt & corrmat_types ==2);
ind3=find(sigcorrs_dt & corrmat_types ==3);
ind4=find(sigcorrs_dt & corrmat_types ==4);
ind5=find(sigcorrs_dt & corrmat_types ==5);
ind6=find(sigcorrs_dt & corrmat_types ==6);
pair_names = corrmat_names(ind);
r_values = sigcorrs_dt(ind) ;
p_values = sigcorrs_p_dt(ind) ;
n_tested = sigcorrs_n_dt(ind) ;
sigcorrs_dt_table = table(pair_names, r_values, p_values, n_tested)
writetable(sigcorrs_dt_table,sprintf('%s/tables/%s.%s.sigcorrs_dt.txt', sitename, cores{k,1}, timeax));

% Add number of significant correlations
sigcorr_dt_no(:,drt-1,k) = [floor(length(ind1)./2),
    floor(length(ind2)./2),
    floor(length(ind3)./2),
    floor(length(ind4)./2),
    floor(length(ind5)./2),
    floor(length(ind6)./2)];

if makefigs
% Plot significant correlations
f3 = figure ;
set(gcf,'Position',[10 200 600 500],'Color','w') ;
imagesc(sigcorrs_dt,[-1 1])
colormap(cmap)
xticks([1:1:numrec]);
xticklabels(recnames);
yticks([1:1:numrec]);
yticklabels(recnames);
xtickangle(45);
title([cores{k,1} ' detrended']);
export_fig(sprintf('%s/figures/%s.%s.corrs_dt.pdf', sitename, cores{k,1}, timeax), '-pdf', '-opengl')
end

close all

end % end if (more than 2 records vs. depth or time)

end % end drt loop (depth / time within core)

end % end k loop (cores)

% SITE SUMMARIES 
% Remember recpairs etc. are pairtypes, depth/year, cores
% first Want to list total of each pairtype in each core, so add across depth/year 
recpairs_sum  = squeeze(sum(recpairs,2)) ;
sigcorr_no_sum  = squeeze(sum(sigcorr_no,2)) ;
sigcorr_dt_no_sum  = squeeze(sum(sigcorr_dt_no,2)) ;

% Write out summary vs. depth 
t_all_d = table(cores(:,1), recpairs_sum', sigcorr_no_sum', sigcorr_dt_no_sum')   
writetable(t_all_d,sprintf('%s/tables/incore.all.txt', sitename));

save(sprintf('%s/corr_matrices.mat',sitename),'site_corr','site_corr_dt');

% All pair lists
% remove dummy first lines
goodrecs = size(allpairs,1);
allpairs = allpairs(2:goodrecs,:);
goodrecs = size(allpairs_dt,1);
allpairs_dt = allpairs_dt(2:goodrecs,:);
save(sprintf('%s/allpairs.mat',sitename),'allpairs','allpairs_dt');

t_summary = table(sum(recpairs_sum,2), sum(sigcorr_no_sum,2), sum(sigcorr_dt_no_sum,2)) ; 
t_summary.Properties.VariableNames = {'RecordPairs','Significant', 'Significant_dt'} ;
t_summary.Properties.RowNames = {'FishFish','FishBgc','BgcBgc','FishPhys','PhysBgc','PhysPhys'} ;
t_summary ;
writetable(t_summary,sprintf('%s/tables/incore.summary.txt',sitename));
